| Title: | Read Morning Pages Into a Data Frame |
|---|---|
| Description: | Read folder of journal-entry files organised by year and month into a data frame. |
| Authors: | Matthew Henderson [aut, cre] (ORCID: <https://orcid.org/0000-0001-7949-8208>) |
| Maintainer: | Matthew Henderson <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.0 |
| Built: | 2026-05-19 06:02:20 UTC |
| Source: | https://github.com/MHenderson/pages2df |
Augment a Pages Data Frame with LaTeX-friendly Text
create_chapter_df(pages)create_chapter_df(pages)
pages |
A data frame containing a column of 'text' and dates 'ymd'. |
A data frame of pages with new columns, tex and tex_w_heading
containing the same data as the text column but chopped into strings
of a near fixed length (without breaking words), with some special LaTeX
characters escaped and, in the case of tex_w_heading with a pre-pended
section heading containing date and time information.
Read Morning Pages from Disk
pages_df(pagespath) read_pages(pagespath, years = c(2021))pages_df(pagespath) read_pages(pagespath, years = c(2021))
pagespath |
Path to morning pages. |
years |
Years to filter. |
A data frame with columns ymd and text.
Summarise Chapters
summarise_chapter_df(pages) create_chapters(pages)summarise_chapter_df(pages) create_chapters(pages)
pages |
A data frame of pages. |
A data frame of chapters.